"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chronoshift_1 = require("chronoshift");
const make_query_1 = __importDefault(require("../../../../client/visualizations/grid/make-query"));
const used_measures_1 = require("../../../../common/models/series/used-measures");
const visualization_query_1 = __importDefault(require("../../../../common/utils/query/visualization-query"));
const execute_query_1 = require("../../../utils/query/execute-query");
function getQuery(essence, timekeeper) {
    return essence.visualization.name === "grid" ? make_query_1.default(essence, timekeeper) : visualization_query_1.default(essence, timekeeper);
}
function start(clause) {
    return clause.values.first().start.toUTCString();
}
function intervalLength(clause) {
    const timeRange = clause.values.first();
    return timeRange.end.getTime() - timeRange.start.getTime();
}
function timeVariables(essence, timekeeper) {
    const timeFilter = essence.currentTimeFilter(timekeeper);
    const timeDimension = essence.getTimeDimension();
    const timeSplit = essence.splits.findSplitForDimension(timeDimension);
    const startTime = start(timeFilter);
    const interval = intervalLength(timeFilter);
    const variables = { startTime, interval };
    if (timeSplit && timeSplit.bucket instanceof chronoshift_1.Duration) {
        variables.granularity = timeSplit.bucket.getDescription();
    }
    if (essence.hasComparison()) {
        const previousTimeFilter = essence.previousTimeFilter(timekeeper);
        variables.shiftedStartTime = start(previousTimeFilter);
    }
    return variables;
}
function logQueryInfo(essence, timekeeper, logger) {
    const nonTimeFilters = essence.filter.removeClause(essence.getTimeDimension().name);
    logger.log(`Visualization query ${essence.description(timekeeper)}`, {
        ...timeVariables(essence, timekeeper),
        dataCube: essence.dataCube.name,
        visualization: essence.visualization.name,
        filters: nonTimeFilters.clauses.map(clause => clause.reference).toArray(),
        splits: essence.splits.splits.map(split => split.reference).toArray(),
        measures: essence.series.series.flatMap(used_measures_1.usedMeasures).toSet().toArray()
    });
}
async function visualizationRoute({ context }, res) {
    const { dataCube, essence, decorator, timekeeper, logger } = context;
    logQueryInfo(essence, timekeeper, logger);
    const query = getQuery(essence, timekeeper);
    const result = await execute_query_1.executeQuery(dataCube, query, essence.timezone, decorator);
    res.json({ result });
}
exports.default = visualizationRoute;
//# sourceMappingURL=visualization.js.map